import java.sql.*;
import java.util.Properties;
import java.util.Vector;

import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableModel;

/** JDBC Driver documentation can be fount at:
 *  jdbc.postgresql.org/documentation/92/index.html **/

public class DBConnection {
	
	public java.sql.Connection conn;
	public java.sql.PreparedStatement st;
	public java.sql.ResultSet rs;


	public DBConnection() {
		
		this.conn = null;
		this.st = null;
		this.rs = null;	
	}
	
	public void loadDriver() {
		
		try
		{
			String driver = "org.postgresql.Driver";
			Class.forName(driver);
			println("JDBC driver loaded!");
		}
		catch (ClassNotFoundException e)
		{
			println("Failed in the method: loadDriver");
			e.printStackTrace();
		}
	}
	
	public void connectToDatabase(String host, String DB, String user, String password) {
		
		println("Establishing a connection to DB " + DB +". ..");
		
		try
		{
			String url = "jdbc:postgresql://" + host + "/" + DB;
			Properties props = new Properties();
			props.setProperty("user", user);
			props.setProperty("password", password);
			this.conn = DriverManager.getConnection(url, props);
		}
		catch (SQLException e)
		{
			println("Failed in the method: connectToDatabase");
			e.printStackTrace();
		}
		
		println("Connection established!");
	}
	
	public void executeSelect(String standing, String major) {
		
			String query = "select * from student where standing like ? and major like ?";
			
			try
			{
				st = conn.prepareStatement(query);
				st.setString(1, standing);
				st.setString(2, major);
				rs = st.executeQuery();
			}
			catch (SQLException e)
			{
				println("Failed in the method: executeSelect");
				e.printStackTrace();
			}
			
	}
	
	public DefaultTableModel rs2tm(ResultSet rs) {

	    ResultSetMetaData md; 
	    int numCols; 
	   
	    Vector<String> colNames = null; 
	    Vector<Vector<Object>> tblData = null; 
	    
	    try 
	    {
	    	/** get the number of columns **/
	    	md = rs.getMetaData();
	    	numCols = md.getColumnCount();
	    	
	    	/** instantiate the vectors  **/
	    	colNames = new Vector<String>();
	    	tblData = new Vector<Vector<Object>>();
	    	
	    	/** get the names of columns **/
	    	for(int i = 1; i <= numCols; i++) 
	    	colNames.add(md.getColumnName(i));

	    	/** get the data of each row **/
	    	while (rs.next()) {
	        
	    		Vector<Object> row = new Vector<Object>();
	        
	    		for(int i = 1; i <= numCols; i++) 
	    		row.add(rs.getObject(i));
	        
	    		tblData.add(row);
	    	}
	    }
	    catch (SQLException e)
	    {
	    	println("Failed in the method: rs2tm");
			e.printStackTrace();
	    }
	    
	    return new DefaultTableModel(tblData, colNames);
	}

	public void clean() {
		
		try
		{
			st.close();
			rs.close();
		}
		catch (SQLException e)
		{
			println("Failed in the method: clean");
			e.printStackTrace();
		}
	}
	
	public static void println(Object msg)
	{
		System.out.println(msg.toString());
	}
	
	public static void print(Object msg)
	{
		System.out.print(msg.toString());
	}
}
